# Logger
This is (Py)thon Ea(sy) Logger
This creates a simple to use python logger, Uses DictConfig for configuring logger.
This Software is in initial stage and will be updated as I move on. Please contribute as you see fit